==> Mk2_201b.zip: var/local/www/restart.php <==
<?php session_start();  
    header ("HTTP/1.1 200 OK");
    include 'tcfunctions.php'; 
?>
<html>  
<head> 
<?php
    $conn = connect();
    htmlheadercontent(); ?>
</head>
<?php    
    bodyhtmlheader();            
    if($_SESSION["logged_in"] == true){    
    infowindow();
    }
    bodyhtmlfooter();
?>
</html>
<?php
reloadcache(4);
?>

<?php function infowindow()
{  ?>
    <div class="centerform">
        <?php windowhtmlheader("Warning!") ?>
            <form>                                
                <table>
                    <tr align="center">
                        <td>
                            The CS TimeClock is being reboooted, <br/>
                            which takes about 15 seconds.<br/>
                            Please login again from your browser<br/>
                            to access the CS TimeClock web interface,<br/>
                            after the clock has rebooted.<br/>
                        </td>
                    </tr>
                    <?php if (isset($_SESSION["newurl"])){ ?>                    
                    <tr>
                        <td height="12px">
                        </td>
                    </tr> 
                    <tr>
                        <td align="center">
                            The CS TimeClock's URL has changed. After the clock has <br/>
                            rebooted, please use the following url to login again: <br/>
                            <a target="_self" href=" <?php echo $newurl ?> "><?php echo $_SESSION["newurl"] ?></a>                             
                        </td>
                    </tr>
                     <?php } ?>                    
                    <tr>
                        <td>
                        </td>
                    </tr>                    
                </table>                                        
            </form>
        <?php windowhtmlfooter() ?>    
    </div>
<?php unset($_SESSION["newurl"]); }  ?>

==> Mk2_202a.zip: var/local/www/restart.php <==
<?php session_start();  
    header ("HTTP/1.1 200 OK");
    include 'tcfunctions.php'; 
?>
<html>  
<head> 
<?php
    $conn = connect();
    htmlheadercontent(); ?>
</head>
<?php    
    bodyhtmlheader();            
    if($_SESSION["logged_in"] == true){    
    infowindow();
    }
    bodyhtmlfooter();
?>
</html>
<?php
reloadcache(4);
?>

<?php function infowindow()
{  ?>
    <div class="centerform">
        <?php windowhtmlheader("Warning!") ?>
            <form>                                
                <table>
                    <tr align="center">
                        <td>
                            The CS TimeClock is being reboooted, <br/>
                            which takes about 15 seconds.<br/>
                            Please login again from your browser<br/>
                            to access the CS TimeClock web interface,<br/>
                            after the clock has rebooted.<br/>
                        </td>
                    </tr>
                    <?php if (isset($_SESSION["newurl"])){ ?>                    
                    <tr>
                        <td height="12px">
                        </td>
                    </tr> 
                    <tr>
                        <td align="center">
                            The CS TimeClock's URL has changed. After the clock has <br/>
                            rebooted, please use the following url to login again: <br/>
                            <a target="_self" href=" <?php echo $newurl ?> "><?php echo $newurl ?></a>                             
                        </td>
                    </tr>
                     <?php } ?>                    
                    <tr>
                        <td>
                        </td>
                    </tr>                    
                </table>                                        
            </form>
        <?php windowhtmlfooter() ?>    
    </div>
<?php unset($_SESSION["newurl"]); }  ?>
